/*
 * DTMF.h - Library for flashing dtmf code.
 * Created by Jose Galvez <juans455@gmail.com>, January 18, 2013.
 * Version 0.1
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * This class creates a handle to the MT8870 DTMF decoder. It creates the 
 * necessary methods to to read its input from a connected sound wave to
 * the chip. Using DTMF DFRobot shield with a microphone connected and a speaker 
 * 
 * This code expects 5 dedicated pins to interface the DTMF decoder and
 * 2 dedicated pins for the speakers to generate DTMF through arduino.
 */
#if defined(ARDUINO) && ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#endif

#include "dtmf.h"

DTMF::DTMF(byte Q1, byte Q2, byte Q3, byte Q4, byte StD)
{
  this->_Q1	= Q1;
  this->_Q2	= Q2;
  this->_Q3	= Q3;
  this->_Q4	= Q4;
  this->_StD	= StD;

  pinMode(Q1, INPUT);
  pinMode(Q2, INPUT);
  pinMode(Q3, INPUT);
  pinMode(Q4, INPUT);
  pinMode(StD, INPUT);
}

/**
 * public DTMF::getDTMF()
 * 
 * Reads the binary ports of the 8870, and calculate its value.
 * Set to output automatically to serial for debugging purposes
 */
int DTMF::getDTMF()
{
  if (digitalRead(_StD) == HIGH) 
  {

    if (digitalRead(_Q1) == HIGH) _reg = 1;  
    else _reg = 0;

    if (digitalRead(_Q2) == HIGH) _reg = _reg + 2;
    if (digitalRead(_Q3) == HIGH) _reg = _reg + 4; 
    if (digitalRead(_Q4) == HIGH) _reg = _reg + 8;

    if (_reg == 10) return '0';  
    else if (_reg == 11) return '*';  
    else if (_reg == 12) return '#'; 
    else return _reg;

    while(1)
    {
      if(digitalRead(_StD) == LOW)
        break;
    }
  }
  else return -1;
}
